CameraControls class

Constructors

CameraControls({bool zoom = true, bool panX = true, bool panY = true, bool orbitX = true, bool orbitY = true})

Properties

hashCode → int
The hash code for this object.
no setterinherited
orbitX ↔ bool
getter/setter pair
orbitY ↔ bool
getter/setter pair
panX ↔ bool
getter/setter pair
panY ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoom ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited