HotKeys class

Constructors

HotKeys({bool directionPressed = false, bool movePressed = false, bool scalePressed = false, bool rotatePressed = false, String currentMove = ''})

Properties

currentMove ↔ String
getter/setter pair
directionPressed ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDirectionX ↔ bool
getter/setter pair
movePressed ↔ bool
getter/setter pair
rotatePressed ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalePressed ↔ bool
getter/setter pair

Methods

getHotKeyType(RawKeyEvent event) → HotKeyTypes
isNumberPressed(String? number) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited