CanvasRects class

Constructors

CanvasRects({required Color color, required Rect rect, String? name, required SelectedType type, int? imageLocation, int layer = 0})

Properties

color ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageLocation ↔ int?
getter/setter pair
layer ↔ int
getter/setter pair
name ↔ String?
getter/setter pair
rect ↔ Rect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ SelectedType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited