Grid class

Constructors

Grid({bool show = true, int height = 18, int width = 30, Size boxSize = const Size(50, 50), double lineWidth = 0.25, Color color = const Color(0x55ffffff), SnapGrid snap = SnapGrid.none})

Properties

boxSize ↔ Size
getter/setter pair
color ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
lineWidth ↔ double
getter/setter pair
offset ↔ Offset
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show ↔ bool
getter/setter pair
snap ↔ SnapGrid
getter/setter pair
width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited