Rectangle class

Constructors

Rectangle({required int x, required int y, required int height, required int width})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
getter/setter pair
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset() → Offset
size() → Size
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited