Material class

Constructors

Material()

Properties

ambient ↔ Vector3
getter/setter pair
diffuse ↔ Vector3
getter/setter pair
emissivity ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ke ↔ Vector3
getter/setter pair
mapBump ↔ String
getter/setter pair
mapKa ↔ String
getter/setter pair
mapKd ↔ String
getter/setter pair
mapKe ↔ String
getter/setter pair
name ↔ String
getter/setter pair
ni ↔ double
getter/setter pair
opacity ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shininess ↔ double
getter/setter pair
specular ↔ Vector3
getter/setter pair
tf ↔ Vector3
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited