Mesh class

Constructors

Mesh({List<Vector3>? vertices, List<Vector3>? normals, List<Offset>? texcoords, List<Triangle>? indices, List<Color>? colors, Image? texture, bool hasTexture = false, Rect? textureRect, String? texturePath, Material? material, String? name})

Properties

colors ↔ List<Color>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasTexture ↔ bool
getter/setter pair
indices ↔ List<Triangle>
getter/setter pair
material ↔ Material
getter/setter pair
name ↔ String?
getter/setter pair
normals ↔ List<Vector3>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texcoords ↔ List<Offset>?
getter/setter pair
texture ↔ Image?
getter/setter pair
texturePath ↔ String?
getter/setter pair
textureRect ↔ Rect?
getter/setter pair
vertices ↔ List<Vector3>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited