Triangle class

Constructors

Triangle(List<int> vertexes, List<int>? normals, List<int>? texture, [double z = 0, bool showFace = false])

Properties

hashCode → int
The hash code for this object.
no setterinherited
normals ↔ List<int>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showFace ↔ bool
getter/setter pair
texture ↔ List<int>?
getter/setter pair
vertexes ↔ List<int>
getter/setter pair
z ↔ double
getter/setter pair

Methods

copyFromArray(List<int> array) → void
copyNormals() → List<int>?
copyTextures() → List<int>?
copyVertexes() → List<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited