GenerateMesh class

Constructors

GenerateMesh()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generatePlane({double size = 0.1, int latSegments = 32, int lonSegments = 64, String? texturePath}) → Future<Mesh>
generateSphere({num radius = 0.5, int latSegments = 32, int lonSegments = 64, String? texturePath}) → Future<Mesh>