ModelRender class

Inheritance

Constructors

ModelRender({Key? key, required LevelScene scene})

Properties

blendMode → BlendMode
final
callback → void Function({required LevelEditorCallbacks call, Offset? details})?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
interactive → bool
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
light → Light
final
onSceneCreated → void Function(LevelScene scene)?
finalinherited
onSceneUpdated → VoidCallback?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene → LevelScene
finalinherited
sortingType → SortingType
final
textureBlendMode → BlendMode
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → LevelEditorState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
generateImage(Size size, List<Object> objects, Image texture) → Future<Image>
generateMap(Canvas canvas, Size size, List<Object> objects, Image? texture) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintersAlgorithm(Triangle? a, Triangle? b) → int
render(Canvas canvas, Size size) → void
rotate(Canvas canvas, double cx, double cy, double angle) → void
storage(Vector3 vertices, Matrix4 transform) → Float64List
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited