RenderMesh class

Constructors

RenderMesh(int vertexCount, int faceCount)

Properties

colors ↔ Int32List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexCount ↔ int
getter/setter pair
indices ↔ List<Triangle?>
getter/setter pair
positions ↔ Float32List
getter/setter pair
positionsZ ↔ Float32List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texcoords ↔ Float32List
getter/setter pair
texture ↔ Image?
getter/setter pair
vertexCount ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited