RotateRect class

Constructors

RotateRect({required double angle, required double off, required Rect rect})

Properties

angle → double
no setter
cx → double
no setter
cy → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
off ↔ double
getter/setter pair
rect ↔ Rect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited