SelectedTile class

Constructors

SelectedTile({int? tileSet, Rect? rect, bool isAnimation = false, int animationLocation = 0, int gridLocation = 0})

Properties

animationLocation ↔ int
getter/setter pair
gridLocation ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAnimation ↔ bool
getter/setter pair
rect ↔ Rect?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileSet ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited