TileAtlas class

Constructors

TileAtlas({int location = 0, bool isTileSet = true, List<Rect>? rect, List<RSTransform>? transform})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isTileSet ↔ bool
getter/setter pair
location ↔ int
getter/setter pair
rect ↔ List<Rect>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform ↔ List<RSTransform>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited