TileGrid class

Constructors

TileGrid({List<Vector3> position = const [], List<Rect> rects = const [], List<List<Rect>>? collisions, GridType type = GridType.manual, int height = 0, int width = 0})

Properties

collisions ↔ List<List<Rect>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
position ↔ List<Vector3>
getter/setter pair
rects ↔ List<Rect>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ GridType
getter/setter pair
width ↔ int
getter/setter pair

Methods

generateCollisions(int length) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited