TileImage class

Constructors

TileImage({Vector3? position, required Size size, String name = '', String path = '', Color color = const Color(0xffff0000), TileGrid? grid, required int offsetHeight})

Properties

color ↔ Color
getter/setter pair
from ↔ Vector2
getter/setter pair
grid ↔ TileGrid
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
offsetHeight ↔ int
getter/setter pair
path ↔ String
getter/setter pair
position ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size
getter/setter pair

Methods

autoGrid(Image image) → Future<void>
getImage(Image init) → Future<Image>
height() → double
manualGrid(int gridWidth, int gridHeight) → void
move(int x, int y, [double sensitivity = 1.0]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updatePosition(Vector2 to, [double sensitivity = 1.0]) → void
updatePositionStart(Vector2 to) → void
zoom(double view) → double

Operators

operator ==(Object other) → bool
The equality operator.
inherited