TileLayers class

Constructors

TileLayers({bool visible = true, List<TileRects>? tiles, required int length, String name = 'Layer'})

Properties

hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tiles ↔ List<TileRects>
getter/setter pair
visible ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited