TileRects class

Constructors

TileRects({int tileSet = 0, Rect rect = const Rect.fromLTWH(0, 0, 0, 0), RSTransform? transform, List<int>? position, bool isAnimation = false, int useAnimation = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAnimation ↔ bool
getter/setter pair
position ↔ List<int>
getter/setter pair
rect ↔ Rect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileSet ↔ int
getter/setter pair
transform ↔ RSTransform
getter/setter pair
useAnimation ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited