RightClick class

A class that determines what to do with the mouse right click or tap and hold options

Constructors

RightClick({required BuildContext context, double width = 150, TextStyle? style, required void onTap(RightClickOptions call)})

Properties

acceptedOptions ↔ List<RightClickOptions>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isMenuOpen ↔ bool
getter/setter pair
onTap ↔ void Function(RightClickOptions call)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair

Methods

closeMenu() → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMenu(String text, Offset offset, List<RightClickOptions> showOptions) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited